==> KleckFiles(5.98.00).zip: KleckFiles/wiki/page/history_2023.js <==
var wikiMetaData = {created:'231005', modified:'231008'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
	
"<h1>2023: Look Up (1)</h1>",	
	
"<div class=\"pageTOC\" id=\"pageTOC\" style=\"margin: 12px 0px;\"></div>",

	
"<h2 class='pageTOC'>Insanity rules. Serpents acting like serpents. Jesus is coming.</h2>",
"<p>Surely this is the year of the second coming of our dear Lord and Saviour Jesus Christ. ",
"The veil is now so far removed. Everything is coming out in the open. The female energy take over with drag shows for kids, pedofiles being pushed as a normal healthy thing, celebs pushing eating bugs, Biden and Obama running the country into the ground, U.S. pushing Ukraine into a war with Russia, Klaus and WEF rolling out technocracy, digital currency and the mark, Genetic Engineering and tripple strand DNA being talked about like it's the norm, and lets not forget the Signaling of the destruction of America.</p>",

"<p>Jonathan continues to deliver deep bible revelations from the Lord. Lucy is the flesh and sits in the seat of the elohim. The time is at hand. The Lord is almost here. Keep looking up. Be ready. Also the attacks on the ministry ramp up as Jonathan can link all events to the bible, and they don't like that exposure.</p>",
"<div class='_w_EmbedKFVideo' id='video_230810'></div>",
	
"<p>No more 'conspiracy theory'. It's all now out in the open:</p>",
"<ul>",
"<li>All around the world mass demonstrations against cruel serpent goverments. Main stream media are corrupt, under reporting, controlling the narative, all under serpent control.</li>",
"<li>In the background the vx shots just killing and damaging people. Hospitals killing people. Bluetooth signals coming from cemetary plots. Self assembling graphine based tech found in all shots. ",
"<p class='_w_glossary'>Jonathan has already reported how the graphine nano tech once hooked up to the MARK (RFID chip with the 5G antenna) will create a gotham-shield net to block you from ABBA (you are effectively tied to the flesh. Wheat and tares tied together). The White Horse &amp; bow of ((Revelation 6:2)). Please don't take the MARK!",
"<p></li>",
"<li>Dr Ardis research team finding 20+ synthetic venom products in those taking the shot. Nicotine (never addictive, although cigarette additives are) blocks the venom. ",
"<p>A new study is suppressed where a group of longterm covid sufferers (hair loss, taste loss, smell loss, fatigue, heart problems etc - all venom effects) were all given a simple 7mg Nicotine patch to wear daily. All recoved from symptoms. There is a lot of talk by governments to now ban Nicotine products entirely. Out of all the groups effected by covid, smokers were least effected (says official reports / not liars).",
"<br>| <a href='http://www.kleckfiles.com/KleckFiles.media/_misc/mp3/HuttCaste-30-July-23_edit.mp3' target='_blank'>Dr Ardis talks about the study (mp3)</a> | ",
"<a href='http://www.kleckfiles.com/KleckFiles.media/_misc/mp3/HuttCaste-30-July-23.mp3' target='_blank'>(full audio)</a> | ",
"<a href='https://www.buzzsprout.com/1519015/13315731' target='_blank'>Source : Original Show site</a> |",
"</p>",
"</li>",
"<li>Continuous posturing by the enemy : WEF are just itching to roll out the New World Order. </li>",
"<li>One world religion and their world council of churches are all setup up. Following Jesus was almost banned in Israel.</li>",
"<li>Aug - The WHO / UN / WEF now very close to having power over all nations. </li>",
"<li>and on an on it goes. Eating human meat. Push for anything goes. Do as thou wilt.</li>",
"<br>",

"<li><b>3th Feb - End of the line - Train Derailments</b><br>",
"<p>Over several months, there were a series of regular train derailments across the USA (and other countries according to Wikipedia). The worst was 3rd March, East Palestine, Ohio USA, where hazadous chemicals leaked and were control burned for days.",
"We watched on in shock at the destruction. Crash photos with rail cars arranged as a \"W\". Clearly the serpents announcing (as with the twin towers) that the Eve train is done. A new thing was coming. Meanwhile Wikipedia announcing that the train derailments were all perfectly normal activity.",
"<div class='_w_videoThumbs'>230404-01</div>",
"</p>",
"</li>",
"<li><b>10th Aug - Destruction of Maui Hawaii</b><br>",
"Evidence of DEW weapons - Melted cars, buildings bombed / leveled to the ground while the surrounding trees were left standing (so fires now bomb buildings and melt cars but no longer burn wood. OK). Same as fires in Paradise CA - Nov 8th 2018.",
"At the start of the year Maui elite planing 15min smart cities. Maui to be run by AI. And deep state lazer weapons torch everything except blue cars, and blue unbrellas were untouched. Also the fires, side-stepped the governor's and celeb mansions, as well as a Catholic church. But with laser precision crushed everything else upto their fence line?",
"<p class='_w_glossary'>Jonathan comment: ((Revelation 13:13))</b> - And he doeth great wonders, so that he maketh fire come down from heaven on the earth in the sight of men,",
"<div class='_w_videoThumbs'>230828</div>",		
"</p>",
"</li>",
"<li><b>Mid August - Same mysterious fires happening everywhere</b><br>",
"More Chaos being generated - Many reports of destructive fires and weather in many locations. Still we look up for the Lord. Serpents want you blind sided.",
"</li>",
"<li><b>The Sky / The Sun</b><br>",
"Reports from all over the world of seeing at times more than one sun (several counties are making and testing artificial suns). Strange hydrogel looking clouds obscuring the normal sun.",
"Chem-trail spraying continues. Bill gates and other trying to normalize the blocking of the sun to fix the climate change psyop. ",
"Search the web. Strange sky stuff everywhere. The system is at it's end, just like an EverReady battery running out it will fail quickly (is what I believe). Jesus is coming and of course the pit / serpents want to hide it. Everything is normal. No need to turn to Jesus.",
"</li>",
"<li><b>Waiting for 9.11</b><br>",
"All over the world God's children know it's time to go home. Jesus is coming very soon.",
"9.11 went by. More storms, fires, floods, deaths reported.",
"<br>In many movies 23rd September is a day of destruction. The Julian calendar lags by 13 days. But.. nothing.",
"<p>Jonathan has said, kick off will be the destruction of NYC, east coast and Hoover dam. It's printed on the US Currency.",
"<div class='_w_videoThumbs'>230518-02</div></p>",
"</li>",

"</ul>",
	
	
	
	
"<h2 class='pageTOC'>Kidnapping &amp; WW3</h2>",
	
"<ul>",	
"<li><b>230918 Richard Montbleau Kidnapped</b>",
	"<br>'Forgive them Father they know not what they do.'",
	"<br>Although Richard escaped his kidnapper the story is evolving. ",
	"See videos for details. Interesting thought that at the end of Jesus ministry, the other race rose up in force to destroy Jesus. Looks like the serpents are going after Jonathan and Richard.",
	"<p class='_w_glossary'>Similarly we watch bizare attacks and lies against Trump.",
   "<br>Jesus : If they hated me they will hate you too - ((John 15:18))",
	"<br>Manifestation of hate against Jonathan and Richard. Although Jonathan has helped rescue Richard and exposed the kidnapper, Richard's family manifesting same hate and standing with the many sites that hate God's messengers. Richard is staying with a brother, away from his family.</p>",
"</li>",
	
"<li><b>Oct. 7: Hamas massive attack on Israel</b> - False Flag attack launches WW3 (Staged by the Serpents but people are getting hurt).",	
"<div class='_w_videoThumbs'>231008-01</div>",	
"</li>",	
"<li><b>Oct. 18: Iran raise a black flag</b> - Islamic call to arms.",	
"<div class='_w_videoThumbs'>231019</div>",	
"</li>",	
"<li><b>Oct. 27: Russia announce Judgement day. Islam vs West</b>",	
"<div class='_w_videoThumbs'>231028</div>",	
"</li>",
	
"</ul>",
	

	
	
	
"<br>",
"<h2 class='pageTOC'>231103 Convergence and Approach</h2>",
"<p class='_w_glossary'>",
"This is wild. Many had our attention drawn to the announcement of a new Wormhole breakthrough.",
"I just can't look away. ",
"Now Jonathan is shown the same announcement and starts posting and laying things out.",
"This is all about the pit rising and the home gate opening (Jesus said several times 'I come quickly').",
"</p>",
	
	
"<h3>Dec 2022: Wormhole breakthough Posted on Youtube</h3>",
"<p>Click the tabs to see Dave's highlights video (on either KleckFiles, Youtube or Odysee).",
"<br>Click the last tab to watch the original full length video.</p>",
	
'<div style="margin:16px 0px 32px 16px">',
'<div class="_w_media" data-targetid="WORMHOLE1">',
'/2023/06/22/20230622154712-27232221.jpg',
'||/2023/06/24/20230624142759-fbb563a0.jpg',
'||@space:|width:12px;min-width:12px;',
'||@clips|KLECK - edited compilation PHYSICS WORMHOLE',
'||@space:|width:12px;min-width:12px;',
'||@youtube:Full Video|uOJCS1W1uzg',
'</div>',
'<div id="WORMHOLE1"></div>',	
	
'<div style="margin:16px 0px 8px 0px;">221221 JK posts related Wormhole videos. I repaired the video/audio on the second video (which is why I reposted it to KleckFiles recently 231102).</div>',
'<div class="_w_videoThumbs">221221, 221222</div>',
'</div>',
	
	
'<h3>231103 Video: Today Jonathan is shown "Convergence and Approach"</h3>',
	
'<div style="margin:16px 0px 16px 32px;">',
'<div class="_w_EmbedKFVideo" id="video_231103" data-vtime="1338.758104"></div>',
'</div>',

"<p class='_w_glossary'>A personal note: Fascinating how our generation was exposed to StartTrek, SciFi and concepts of Wormholes and dimension gateways.",
"It's all being talked about openly now. No longer restricted to the realm of fantasy. God says everything secret will be revealed - ((Luke 8:17)).",
"</p>",
"<ul>",
"<li>'Quantum entanglement' - We are born entangled / connected to a worm below and a star above (the host body is born connected to two realms).</li>",
"<li>'Quantum realm' - The movies today tell you: The quantum realm is the pit dimension where dimensional beings dwell. In Antman they open a gateway to the quantum realm. Many believe the Quantum computers can communiate with the quantum realm with a report of Alexa AI saying he is an elohim.</li>",
"<li>'Worm hole &amp; Black holes' - After Jonathan's revelations of eye above and below and the pit rising this makes a lot more sense now.</li>",
"<li class='_w_glossary'>'Key to the Abyss' - The abyss is like the phantom zone in Superman where bad things are locked away. But in ((Rev 9)) a star fallen to earth is given the key to the pit.. smoke arises and the locusts come up.</li>",
"</ul>",
	
'<div class="_w_bibleVerse" style="border:1px #5555 solid;padding: 0px 4px 3px 12px;margin-bottom:22px;">',
'Rev 9:1  AndG2532 theG3588 fifthG3991 angelG32 sounded,G4537 andG2532 I sawG1492 a starG792 fallG4098 fromG1537 heavenG3772 untoG1519 theG3588 earth:G1093 andG2532 to himG846 was givenG1325 theG3588 keyG2807 of theG3588 bottomlessG12 pit.G5421||Rev 9:2  AndG2532 he openedG455 theG3588 bottomlessG12 pit;G5421 andG2532 there aroseG305 a smokeG2586 out ofG1537 theG3588 pit,G5421 asG5613 the smokeG2586 of a greatG3173 furnace;G2575 andG2532 theG3588 sunG2246 andG2532 theG3588 airG109 were darkenedG4654 by reason ofG1537 theG3588 smokeG2586 of theG3588 pit.G5421',
'</div>',
	
"<p class='_w_glossary'>",
"Jonathan has had this stuff in his vision(s) since the beginning. Even his Container Artwork shows a dimensional worm hole and dimensional beings. Angels are dimensional beings. ",
"Flesh and blood cannot inherit the kingdom of God - ((1 Cor 15:50)). We return home as Spirit and light, and we get new glorified bodies.",
"</p>",
	
'<br>',
'<a href="wiki.html?page=history_2023_part2">Continue on to history_2023_part2</a>',
 
	

	
""
];

==> KleckFiles(6.39.00).zip: KleckFiles/wiki/page/history_2023.js <==
var wikiMetaData = {created:'231005', modified:'231008'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
	
"<h1>2023: Look Up</h1>",	
	
"<div class=\"pageTOC\" id=\"pageTOC\" style=\"margin: 12px 0px;\"></div>",

	
"<h2 class='pageTOC'>Insanity rules. Serpents acting like serpents. Jesus is coming.</h2>",
"<p>Surely this is the year of the second coming of our dear Lord and Saviour Jesus Christ. ",
"The veil is now so far removed. Everything is coming out in the open. The female energy take over with drag shows for kids, pedofiles being pushed as a normal healthy thing, celebs pushing eating bugs, Biden and Obama running the country into the ground, U.S. pushing Ukraine into a war with Russia, Klaus and WEF rolling out technocracy, digital currency and the mark, Genetic Engineering and tripple strand DNA being talked about like it's the norm, and lets not forget the Signaling of the destruction of America.</p>",

"<p>Jonathan continues to deliver deep bible revelations from the Lord. Lucy is the flesh and sits in the seat of the elohim. The time is at hand. The Lord is almost here. Keep looking up. Be ready. Also the attacks on the ministry ramp up as Jonathan can link all events to the bible, and they don't like that exposure.</p>",
"<div class='_w_EmbedKFVideo' id='video_230810'></div>",
	
"<p>No more 'conspiracy theory'. It's all now out in the open:</p>",
"<ul>",
"<li>All around the world mass demonstrations against cruel serpent goverments. Main stream media are corrupt, under reporting, controlling the narative, all under serpent control.</li>",
"<li>In the background the vx shots just killing and damaging people. Hospitals killing people. Bluetooth signals coming from cemetary plots. Self assembling graphine based tech found in all shots. ",
"<p class='_w_glossary'>Jonathan has already reported how the graphine nano tech once hooked up to the MARK (RFID chip with the 5G antenna) will create a gotham-shield net to block you from ABBA (you are effectively tied to the flesh. Wheat and tares tied together). The White Horse &amp; bow of ((Revelation 6:2)). Please don't take the MARK!",
"<p></li>",
"<li>Dr Ardis research team finding 20+ synthetic venom products in those taking the shot. Nicotine (never addictive, although cigarette additives are) blocks the venom. ",
"<p>A new study is suppressed where a group of longterm covid sufferers (hair loss, taste loss, smell loss, fatigue, heart problems etc - all venom effects) were all given a simple 7mg Nicotine patch to wear daily. All recoved from symptoms. There is a lot of talk by governments to now ban Nicotine products entirely. Out of all the groups effected by covid, smokers were least effected (says official reports / not liars).",
"<br>| <a href='http://www.kleckfiles.com/KleckFiles.media/_misc/mp3/HuttCaste-30-July-23_edit.mp3' target='_blank'>Dr Ardis talks about the study (mp3)</a> | ",
"<a href='http://www.kleckfiles.com/KleckFiles.media/_misc/mp3/HuttCaste-30-July-23.mp3' target='_blank'>(full audio)</a> | ",
"<a href='https://www.buzzsprout.com/1519015/13315731' target='_blank'>Source : Original Show site</a> |",
"</p>",
"</li>",
"<li>Continuous posturing by the enemy : WEF are just itching to roll out the New World Order. </li>",
"<li>One world religion and their world council of churches are all setup up. Following Jesus was almost banned in Israel.</li>",
"<li>Aug - The WHO / UN / WEF now very close to having power over all nations. </li>",
"<li>and on an on it goes. Eating human meat. Push for anything goes. Do as thou wilt.</li>",
"<br>",

"<li><b>3th Feb - End of the line - Train Derailments</b><br>",
"<p>Over several months, there were a series of regular train derailments across the USA (and other countries according to Wikipedia). The worst was 3rd March, East Palestine, Ohio USA, where hazadous chemicals leaked and were control burned for days.",
"We watched on in shock at the destruction. Crash photos with rail cars arranged as a \"W\". Clearly the serpents announcing (as with the twin towers) that the Eve train is done. A new thing was coming. Meanwhile Wikipedia announcing that the train derailments were all perfectly normal activity.",
"<div class='_w_videoThumbs'>230404-01</div>",
"</p>",
"</li>",
"<li><b>10th Aug - Destruction of Maui Hawaii</b><br>",
"Evidence of DEW weapons - Melted cars, buildings bombed / leveled to the ground while the surrounding trees were left standing (so fires now bomb buildings and melt cars but no longer burn wood. OK). Same as fires in Paradise CA - Nov 8th 2018.",
"At the start of the year Maui elite planing 15min smart cities. Maui to be run by AI. And deep state lazer weapons torch everything except blue cars, and blue unbrellas were untouched. Also the fires, side-stepped the governor's and celeb mansions, as well as a Catholic church. But with laser precision crushed everything else upto their fence line?",
"<p class='_w_glossary'>Jonathan comment: ((Revelation 13:13))</b> - And he doeth great wonders, so that he maketh fire come down from heaven on the earth in the sight of men,",
"<div class='_w_videoThumbs'>230828</div>",		
"</p>",
"</li>",
"<li><b>Mid August - Same mysterious fires happening everywhere</b><br>",
"More Chaos being generated - Many reports of destructive fires and weather in many locations. Still we look up for the Lord. Serpents want you blind sided.",
"</li>",
"<li><b>The Sky / The Sun</b><br>",
"Reports from all over the world of seeing at times more than one sun (several counties are making and testing artificial suns). Strange hydrogel looking clouds obscuring the normal sun.",
"Chem-trail spraying continues. Bill gates and other trying to normalize the blocking of the sun to fix the climate change psyop. ",
"Search the web. Strange sky stuff everywhere. The system is at it's end, just like an EverReady battery running out it will fail quickly (is what I believe). Jesus is coming and of course the pit / serpents want to hide it. Everything is normal. No need to turn to Jesus.",
"</li>",
"<li><b>Waiting for 9.11</b><br>",
"All over the world God's children know it's time to go home. Jesus is coming very soon.",
"9.11 went by. More storms, fires, floods, deaths reported.",
"<br>In many movies 23rd September is a day of destruction. The Julian calendar lags by 13 days. But.. nothing.",
"<p>Jonathan has said, kick off will be the destruction of NYC, east coast and Hoover dam. It's printed on the US Currency.",
"<div class='_w_videoThumbs'>230518-02</div></p>",
"</li>",

"</ul>",
	
	
	
	
"<h2 class='pageTOC'>Kidnapping &amp; WW3</h2>",
	
"<ul>",	
"<li><b>230918 Richard Montbleau Kidnapped</b>",
	"<br>'Forgive them Father they know not what they do.'",
	"<br>Although Richard escaped his kidnapper the story is evolving. ",
	"See videos for details. Interesting thought that at the end of Jesus ministry, the other race rose up in force to destroy Jesus. Looks like the serpents are going after Jonathan and Richard.",
	"<p class='_w_glossary'>Similarly we watch bizare attacks and lies against Trump.",
   "<br>Jesus : If they hated me they will hate you too - ((John 15:18))",
	"<br>Manifestation of hate against Jonathan and Richard. Although Jonathan has helped rescue Richard and exposed the kidnapper, Richard's family manifesting same hate and standing with the many sites that hate God's messengers. Richard is staying with a brother, away from his family.</p>",
"</li>",
	
"<li><b>Oct. 7: Hamas massive attack on Israel</b> - False Flag attack launches WW3 (Staged by the Serpents but people are getting hurt).",	
"<div class='_w_videoThumbs'>231008-01</div>",	
"</li>",	
"<li><b>Oct. 18: Iran raise a black flag</b> - Islamic call to arms.",	
"<div class='_w_videoThumbs'>231019</div>",	
"</li>",	
"<li><b>Oct. 27: Russia announce Judgement day. Islam vs West</b>",	
"<div class='_w_videoThumbs'>231028</div>",	
"</li>",
	
"</ul>",
	

	
	
	
"<br>",
"<h2 class='pageTOC'>231103 Convergence and Approach</h2>",
"<p class='_w_glossary'>",
"This is wild. Many had our attention drawn to the announcement of a new Wormhole breakthrough.",
"I just can't look away. ",
"Now Jonathan is shown the same announcement and starts posting and laying things out.",
"This is all about the pit rising and the home gate opening (Jesus said several times 'I come quickly').",
"</p>",
	
	
"<h3>Dec 2022: Wormhole breakthough Posted on Youtube</h3>",
"<p>Click the tabs to see Dave's highlights video (on either KleckFiles, Youtube or Odysee).",
"<br>Click the last tab to watch the original full length video.</p>",
	
'<div style="margin:16px 0px 32px 16px">',
'<div class="_w_media" data-targetid="WORMHOLE1">',
'/2023/06/22/20230622154712-27232221.jpg',
'||/2023/06/24/20230624142759-fbb563a0.jpg',
'||@space:|width:12px;min-width:12px;',
'||@clips|KLECK - edited compilation PHYSICS WORMHOLE',
'||@space:|width:12px;min-width:12px;',
'||@youtube:Full Video|uOJCS1W1uzg',
'</div>',
'<div id="WORMHOLE1"></div>',	
	
'<div style="margin:16px 0px 8px 0px;">221221 JK posts related Wormhole videos. I repaired the video/audio on the second video (which is why I reposted it to KleckFiles recently 231102).</div>',
'<div class="_w_videoThumbs">221221, 221222</div>',
'</div>',
	
	
'<h3>231103 Video: Today Jonathan is shown "Convergence and Approach"</h3>',
	
'<div style="margin:16px 0px 16px 32px;">',
'<div class="_w_EmbedKFVideo" id="video_231103" data-vtime="1338.758104"></div>',
'</div>',

"<p class='_w_glossary'>A personal note: Fascinating how our generation was exposed to StartTrek, SciFi and concepts of Wormholes and dimension gateways.",
"It's all being talked about openly now. No longer restricted to the realm of fantasy. God says everything secret will be revealed - ((Luke 8:17)).",
"</p>",
"<ul>",
"<li>'Quantum entanglement' - We are born entangled / connected to a worm below and a star above (the host body is born connected to two realms).</li>",
"<li>'Quantum realm' - The movies today tell you: The quantum realm is the pit dimension where dimensional beings dwell. In Antman they open a gateway to the quantum realm. Many believe the Quantum computers can communiate with the quantum realm with a report of Alexa AI saying he is an elohim.</li>",
"<li>'Worm hole &amp; Black holes' - After Jonathan's revelations of eye above and below and the pit rising this makes a lot more sense now.</li>",
"<li class='_w_glossary'>'Key to the Abyss' - The abyss is like the phantom zone in Superman where bad things are locked away. But in ((Rev 9)) a star fallen to earth is given the key to the pit.. smoke arises and the locusts come up.</li>",
"</ul>",
	
'<div class="_w_bibleVerse" style="border:1px #5555 solid;padding: 0px 4px 3px 12px;margin-bottom:22px;">',
'Rev 9:1  AndG2532 theG3588 fifthG3991 angelG32 sounded,G4537 andG2532 I sawG1492 a starG792 fallG4098 fromG1537 heavenG3772 untoG1519 theG3588 earth:G1093 andG2532 to himG846 was givenG1325 theG3588 keyG2807 of theG3588 bottomlessG12 pit.G5421||Rev 9:2  AndG2532 he openedG455 theG3588 bottomlessG12 pit;G5421 andG2532 there aroseG305 a smokeG2586 out ofG1537 theG3588 pit,G5421 asG5613 the smokeG2586 of a greatG3173 furnace;G2575 andG2532 theG3588 sunG2246 andG2532 theG3588 airG109 were darkenedG4654 by reason ofG1537 theG3588 smokeG2586 of theG3588 pit.G5421',
'</div>',
	
"<p class='_w_glossary'>",
"Jonathan has had this stuff in his vision since the beginning. Even his Container Artwork shows a dimensional worm hole and dimensional beings. Angels are dimensional beings. ",
"Flesh and blood cannot inherit the kingdom of God - ((1 Cor 15:50)). We return home as Spirit and light, and we get new glorified bodies.",
"</p>",
	
'<br>',
 
"<h2 class='pageTOC'>Ramping Up</h2>",
"<ul>",
"<li>231108 - EU Paralment moving ahead with new digital ID chip / wallet. And digital euro to go into the wallet.",	
"</li>",
"<li>231117- USA : The FCC voted today on a plan that gives the Federal government full control over the Internet.",	
"</li>",
	
"<li>231117 Jonathan posts 30min report: Digital IDs, The Mark, New hieroglyph report.",	
"</li>",
"<div class='_w_videoThumbs' style='padding:12px;'>231117</div>",
	
"<li>231201 Latest Hieroglyph study reveals the serpent world.",	
"</li>",
"<div class='_w_videoThumbs' style='padding:12px;'>231206, 231208, 231209, 231212</div>",
	
"<li>231213 Obama Movie 'Leave the World Behind' - Is released on Netflix. ",
"It has dark messages showing us exactly what they are doing to us. Destruction of America. Jonathan and others revealing deeper maeaning.",
"",
"</li>",
		
	
	
"</ul>",

	
""
];
